@@ -7,7 +7,7 @@ from matplotlib import pyplot as plt
 from mrftools import DictionaryParameters, SequenceParameters
 
 class Simulation: 
-    def __init__(self,sequenceParameters, dictionaryParameters, name="", numTimepoints = -1, phaseRange=(-2*np.pi, 2*np.pi), numSpins=1, results=[], truncationMatrix=[], truncatedResults=[]):
+    def __init__(self,sequenceParameters, dictionaryParameters, name="", numTimepoints = -1, phaseRange=(-2*np.pi, 2*np.pi), numSpins=1, fullResults=[], truncationMatrix=[], truncatedResults=[]):
         self.sequenceParameters = sequenceParameters
         self.dictionaryParameters = dictionaryParameters
         if numTimepoints == -1:
@@ -15,7 +15,7 @@ class Simulation:
         self.numTimepoints = numTimepoints
         self.phaseRange = phaseRange
         self.numSpins = numSpins
-        self.results = results
+        self.fullResults = fullResults
         self.truncationMatrix = truncationMatrix
         self.truncatedResults = truncatedResults
         if not name:
@@ -126,7 +126,7 @@ class Simulation:
         print("Simulating " + str(numBatches) + " batch(s) of " + str(dictEntriesPerBatch) + " dictionary entries")
         Mxy = np.zeros((self.numTimepoints, len(self.dictionaryParameters.entries)), np.complex128)
         for i in range(numBatches):
-            print("Starting Batch: " + str(i))
+            print("Batch: " + str(i))
             firstDictEntry = i*dictEntriesPerBatch
             lastDictEntry = firstDictEntry+dictEntriesPerBatch
             T1s.clear();T2s.clear();B1s.clear()
@@ -137,22 +137,23 @@ class Simulation:
             Mx0,My0,Mz0 = self.ExecuteNumbaSimulation(self.numTimepoints, np.asarray(T1s),np.asarray(T2s),np.asarray(B1s),np.asarray(TRs),np.asarray(TEs),np.asarray(FAs),phaseValues)
             Mx,My,Mz = self.ParallizedMeans(Mx0,My0,Mz0)
             Mxy[:,firstDictEntry:lastDictEntry] = Mx+(My*1j)
-        self.results = Mxy
-        return self.results
+        self.fullResults = Mxy
 
     def CalculateSVD(self, truncationNumber):
-        dictionary = self.results.transpose()
+        dictionary = np.transpose(self.fullResults)
         dictionaryNorm = np.sqrt(np.sum(np.power(np.abs(dictionary[:,:]),2),1))
         dictionaryShape = np.shape(dictionary)
         normalizedDictionary = np.zeros_like(dictionary)
         for i in range(dictionaryShape[0]):
             normalizedDictionary[i,:] = dictionary[i,:]/dictionaryNorm[i]
-        (u,s,v) = np.linalg.svd(normalizedDictionary, full_matrices=False, compute_uv=True, hermitian=False)
-        truncationMatrix = v[:,0:truncationNumber]
-        truncatedResults = np.matmul(normalizedDictionary,truncationMatrix).transpose()
-        return(truncationMatrix, truncatedResults)
+        (u,s,v) = np.linalg.svd(normalizedDictionary, full_matrices=False)
+        vt = np.transpose(v)
+        self.truncationMatrix = vt[:,0:truncationNumber]
+        print(np.shape(normalizedDictionary))
+        print(np.shape(self.truncationMatrix))
+        self.truncatedResults = np.matmul(normalizedDictionary,self.truncationMatrix).transpose()
 
-    def Export(self, filename, force=False):
+    def Export(self, filename, force=False, includeFullResults=True, includeSVDResults=True):
         if ".mrf" in filename:
             outfile = h5py.File(filename, "a")
             try:
@@ -175,21 +176,34 @@ class Simulation:
                 simulation["sequenceParameters"] = outfile["/sequenceParameters/"+self.sequenceParameters.name]
                 self.dictionaryParameters.Export(filename, force)
                 simulation["dictionaryParameters"] = outfile["/dictionaryParameters/"+self.dictionaryParameters.name]
-                simulation["results"] = self.results
-                simulation["truncationMatrix"] = self.truncationMatrix
-                simulation["truncatedResults"] = self.truncatedResults
+                if includeFullResults:
+                    simulation["fullResults"] = self.fullResults
+                else:
+                    simulation["fullResults"] = []
+                if includeSVDResults:
+                    simulation["truncationMatrix"] = self.truncationMatrix
+                    simulation["truncatedResults"] = self.truncatedResults
+                else:
+                    simulation["truncationMatrix"] = []
+                    simulation["truncatedResults"] = []
                 outfile.close()
         else:
             print("Input is not a .mrf file")
 
-    def Plot(self, numTimepoints=-1, dictionaryEntryNumbers=[]):
+    def GetAverageTimecourse(self, dictionaryEntryNumbers:list):
+        np.shape(np.average(self.fullResults[:,dictionaryEntryNumbers], 1))
+
+    def Plot(self, numTimepoints=-1, dictionaryEntryNumbers=[], plotTruncated=False):
         if numTimepoints == -1:
             numTimepoints = len(self.sequenceParameters.timepoints)
         if dictionaryEntryNumbers == []:
             dictionaryEntryNumbers = [int(len(self.dictionaryParameters.entries)/2)]
         ax = plt.subplot(1,1,1)
         for entry in dictionaryEntryNumbers:
-            plt.plot(range(numTimepoints), abs(self.results[:,entry]), label=str(self.dictionaryParameters.entries[entry]))
+            if(plotTruncated):
+                plt.plot(abs(self.truncatedResults[:,entry]), label=str(self.dictionaryParameters.entries[entry]))
+            else:
+                plt.plot(abs(self.fullResults[:,entry]), label=str(self.dictionaryParameters.entries[entry]))
         ax.legend()
 
     @staticmethod
@@ -201,14 +215,14 @@ class Simulation:
             simulationNumTimepoints = simulationGroup.attrs.get("numTimepoints")
             simulationPhaseRange = simulationGroup.attrs.get("phaseRange")
             simulationNumSpins = simulationGroup.attrs.get("numSpins")
-            simulationResults = simulationGroup["results"][:]
+            simulationFullResults = simulationGroup["fullResults"][:]
             simulationTruncationMatrix = simulationGroup["truncationMatrix"][:]
             simulationTruncatedResults = simulationGroup["truncatedResults"][:]
             sequenceParametersGroup = simulationGroup["sequenceParameters"]
             importedSequenceParameters = SequenceParameters(sequenceParametersGroup.attrs.get("name"), sequenceParametersGroup["timepoints"][:])
             dictionaryParametersGroup = simulationGroup["dictionaryParameters"]
             importedDictionaryParameters = DictionaryParameters(dictionaryParametersGroup.attrs.get("name"), dictionaryParametersGroup["entries"][:])
-            new_simulation = Simulation(importedSequenceParameters, importedDictionaryParameters, simulationName, simulationNumTimepoints, simulationPhaseRange, simulationNumSpins, simulationResults, simulationTruncationMatrix, simulationTruncatedResults)
+            new_simulation = Simulation(importedSequenceParameters, importedDictionaryParameters, simulationName, simulationNumTimepoints, simulationPhaseRange, simulationNumSpins, simulationFullResults, simulationTruncationMatrix, simulationTruncatedResults)
             infile.close()
             return new_simulation
         else:
